Class: LoyaltyApIs::AccessCodeResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- LoyaltyApIs::AccessCodeResponse
- Defined in:
- lib/loyalty_ap_is/models/access_code_response.rb
Overview
AccessCodeResponse Model.
Instance Attribute Summary collapse
-
#access_code ⇒ String
AccessCode provided by Shell after it redirects the user to the partner's URL.
-
#expires_in ⇒ Integer
Indicates the number of seconds until the accessCode expires.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(access_code: SKIP, expires_in: SKIP, additional_properties: nil) ⇒ AccessCodeResponse
constructor
A new instance of AccessCodeResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(access_code: SKIP, expires_in: SKIP, additional_properties: nil) ⇒ AccessCodeResponse
Returns a new instance of AccessCodeResponse.
42 43 44 45 46 47 48 49 50 |
# File 'lib/loyalty_ap_is/models/access_code_response.rb', line 42 def initialize(access_code: SKIP, expires_in: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @access_code = access_code unless access_code == SKIP @expires_in = expires_in unless expires_in == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#access_code ⇒ String
AccessCode provided by Shell after it redirects the user to the partner's URL.
15 16 17 |
# File 'lib/loyalty_ap_is/models/access_code_response.rb', line 15 def access_code @access_code end |
#expires_in ⇒ Integer
Indicates the number of seconds until the accessCode expires
19 20 21 |
# File 'lib/loyalty_ap_is/models/access_code_response.rb', line 19 def expires_in @expires_in end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/loyalty_ap_is/models/access_code_response.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. access_code = hash.key?('accessCode') ? hash['accessCode'] : SKIP expires_in = hash.key?('expiresIn') ? hash['expiresIn'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AccessCodeResponse.new(access_code: access_code, expires_in: expires_in, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/loyalty_ap_is/models/access_code_response.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['access_code'] = 'accessCode' @_hash['expires_in'] = 'expiresIn' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/loyalty_ap_is/models/access_code_response.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/loyalty_ap_is/models/access_code_response.rb', line 30 def self.optionals %w[ access_code expires_in ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/loyalty_ap_is/models/access_code_response.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} access_code: #{@access_code.inspect}, expires_in: #{@expires_in.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/loyalty_ap_is/models/access_code_response.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} access_code: #{@access_code}, expires_in: #{@expires_in},"\ " additional_properties: #{@additional_properties}>" end |