Class: LoyaltyApIs::BadRequestError

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/loyalty_ap_is/models/bad_request_error.rb

Overview

Request is missing a parameter so the server cannot proceed with the request.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(fault: SKIP) ⇒ BadRequestError

Returns a new instance of BadRequestError.



36
37
38
# File 'lib/loyalty_ap_is/models/bad_request_error.rb', line 36

def initialize(fault: SKIP)
  @fault = fault unless fault == SKIP
end

Instance Attribute Details

#faultFault

TODO: Write general description for this method

Returns:



15
16
17
# File 'lib/loyalty_ap_is/models/bad_request_error.rb', line 15

def fault
  @fault
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



41
42
43
44
45
46
47
48
49
# File 'lib/loyalty_ap_is/models/bad_request_error.rb', line 41

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  fault = Fault.from_hash(hash['fault']) if hash['fault']

  # Create object from extracted values.
  BadRequestError.new(fault: fault)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/loyalty_ap_is/models/bad_request_error.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['fault'] = 'fault'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
# File 'lib/loyalty_ap_is/models/bad_request_error.rb', line 32

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
28
29
# File 'lib/loyalty_ap_is/models/bad_request_error.rb', line 25

def self.optionals
  %w[
    fault
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



58
59
60
61
# File 'lib/loyalty_ap_is/models/bad_request_error.rb', line 58

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} fault: #{@fault.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



52
53
54
55
# File 'lib/loyalty_ap_is/models/bad_request_error.rb', line 52

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} fault: #{@fault}>"
end