Class: LoyaltyApIs::BalanceCurrencyAmount

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/loyalty_ap_is/models/balance_currency_amount.rb

Overview

BalanceCurrencyAmount Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(currency_type:, amounts: SKIP, additional_properties: nil) ⇒ BalanceCurrencyAmount

Returns a new instance of BalanceCurrencyAmount.



40
41
42
43
44
45
46
47
# File 'lib/loyalty_ap_is/models/balance_currency_amount.rb', line 40

def initialize(currency_type:, amounts: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @currency_type = currency_type
  @amounts = amounts unless amounts == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#amountsArray[BalanceAmountDetail]

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/loyalty_ap_is/models/balance_currency_amount.rb', line 18

def amounts
  @amounts
end

#currency_typeBalanceCurrencyType

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/loyalty_ap_is/models/balance_currency_amount.rb', line 14

def currency_type
  @currency_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/loyalty_ap_is/models/balance_currency_amount.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  currency_type = hash.key?('currencyType') ? hash['currencyType'] : nil
  # Parameter is an array, so we need to iterate through it
  amounts = nil
  unless hash['amounts'].nil?
    amounts = []
    hash['amounts'].each do |structure|
      amounts << (BalanceAmountDetail.from_hash(structure) if structure)
    end
  end

  amounts = SKIP unless hash.key?('amounts')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BalanceCurrencyAmount.new(currency_type: currency_type,
                            amounts: amounts,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/loyalty_ap_is/models/balance_currency_amount.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['currency_type'] = 'currencyType'
  @_hash['amounts'] = 'amounts'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/loyalty_ap_is/models/balance_currency_amount.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
# File 'lib/loyalty_ap_is/models/balance_currency_amount.rb', line 29

def self.optionals
  %w[
    amounts
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



87
88
89
90
91
# File 'lib/loyalty_ap_is/models/balance_currency_amount.rb', line 87

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} currency_type: #{@currency_type.inspect}, amounts: #{@amounts.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
84
# File 'lib/loyalty_ap_is/models/balance_currency_amount.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} currency_type: #{@currency_type}, amounts: #{@amounts},"\
  " additional_properties: #{@additional_properties}>"
end