Class: LoyaltyApIs::ConsumersBalances401ErrorException

Inherits:
APIException
  • Object
show all
Defined in:
lib/loyalty_ap_is/exceptions/consumers_balances401_error_exception.rb

Overview

Consumers Balances 401 Error class.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(reason, response) ⇒ ConsumersBalances401ErrorException

The constructor.

Parameters:

  • reason (String)

    The reason for raising an exception.

  • response (HttpResponse)

    The HttpReponse of the API call.



27
28
29
30
31
# File 'lib/loyalty_ap_is/exceptions/consumers_balances401_error_exception.rb', line 27

def initialize(reason, response)
  super(reason, response)
  hash = APIHelper.json_deserialize(@response.raw_body)
  unbox(hash)
end

Instance Attribute Details

#errorObject

TODO: Write general description for this method

Returns:

  • (Object)


22
23
24
# File 'lib/loyalty_ap_is/exceptions/consumers_balances401_error_exception.rb', line 22

def error
  @error
end

#error_codeInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/loyalty_ap_is/exceptions/consumers_balances401_error_exception.rb', line 14

def error_code
  @error_code
end

#messageString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/loyalty_ap_is/exceptions/consumers_balances401_error_exception.rb', line 18

def message
  @message
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



51
52
53
54
55
# File 'lib/loyalty_ap_is/exceptions/consumers_balances401_error_exception.rb', line 51

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} error_code: #{@error_code.inspect}, message: #{@message.inspect}, error:"\
  " #{@error.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



45
46
47
48
# File 'lib/loyalty_ap_is/exceptions/consumers_balances401_error_exception.rb', line 45

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} error_code: #{@error_code}, message: #{@message}, error: #{@error}>"
end

#unbox(hash) ⇒ Object

Populates this object by extracting properties from a hash. response body.

Parameters:

  • hash (Hash)

    The deserialized response sent by the server in the



36
37
38
39
40
41
42
# File 'lib/loyalty_ap_is/exceptions/consumers_balances401_error_exception.rb', line 36

def unbox(hash)
  return nil unless hash

  @error_code = hash.key?('errorCode') ? hash['errorCode'] : nil
  @message = hash.key?('message') ? hash['message'] : nil
  @error = hash.key?('error') ? hash['error'] : nil
end