Class: LoyaltyApIs::ConsumersBalances422ErrorException
- Inherits:
-
APIException
- Object
- CoreLibrary::ApiException
- APIException
- LoyaltyApIs::ConsumersBalances422ErrorException
- Defined in:
- lib/loyalty_ap_is/exceptions/consumers_balances422_error_exception.rb
Overview
Consumers Balances 422 Error class.
Instance Attribute Summary collapse
-
#error ⇒ Object
TODO: Write general description for this method.
-
#error_code ⇒ Integer
TODO: Write general description for this method.
-
#message ⇒ String
TODO: Write general description for this method.
Instance Method Summary collapse
-
#initialize(reason, response) ⇒ ConsumersBalances422ErrorException
constructor
The constructor.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
-
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash.
Constructor Details
#initialize(reason, response) ⇒ ConsumersBalances422ErrorException
The constructor.
27 28 29 30 31 |
# File 'lib/loyalty_ap_is/exceptions/consumers_balances422_error_exception.rb', line 27 def initialize(reason, response) super(reason, response) hash = APIHelper.json_deserialize(@response.raw_body) unbox(hash) end |
Instance Attribute Details
#error ⇒ Object
TODO: Write general description for this method
22 23 24 |
# File 'lib/loyalty_ap_is/exceptions/consumers_balances422_error_exception.rb', line 22 def error @error end |
#error_code ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/loyalty_ap_is/exceptions/consumers_balances422_error_exception.rb', line 14 def error_code @error_code end |
#message ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/loyalty_ap_is/exceptions/consumers_balances422_error_exception.rb', line 18 def @message end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
51 52 53 54 55 |
# File 'lib/loyalty_ap_is/exceptions/consumers_balances422_error_exception.rb', line 51 def inspect class_name = self.class.name.split('::').last "<#{class_name} error_code: #{@error_code.inspect}, message: #{@message.inspect}, error:"\ " #{@error.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
45 46 47 48 |
# File 'lib/loyalty_ap_is/exceptions/consumers_balances422_error_exception.rb', line 45 def to_s class_name = self.class.name.split('::').last "<#{class_name} error_code: #{@error_code}, message: #{@message}, error: #{@error}>" end |
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash. response body.
36 37 38 39 40 41 42 |
# File 'lib/loyalty_ap_is/exceptions/consumers_balances422_error_exception.rb', line 36 def unbox(hash) return nil unless hash @error_code = hash.key?('errorCode') ? hash['errorCode'] : nil @message = hash.key?('message') ? hash['message'] : nil @error = hash.key?('error') ? hash['error'] : nil end |