Class: LoyaltyApIs::CustomerBalances
- Defined in:
- lib/loyalty_ap_is/models/customer_balances.rb
Overview
CustomerBalances Model.
Instance Attribute Summary collapse
-
#balances ⇒ Array[BalanceAmount]
A list of points balances.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(balances: SKIP, additional_properties: nil) ⇒ CustomerBalances
constructor
A new instance of CustomerBalances.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(balances: SKIP, additional_properties: nil) ⇒ CustomerBalances
Returns a new instance of CustomerBalances.
35 36 37 38 39 40 41 |
# File 'lib/loyalty_ap_is/models/customer_balances.rb', line 35 def initialize(balances: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @balances = balances unless balances == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#balances ⇒ Array[BalanceAmount]
A list of points balances. Not nullable, an empty array is used instead.
14 15 16 |
# File 'lib/loyalty_ap_is/models/customer_balances.rb', line 14 def balances @balances end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/loyalty_ap_is/models/customer_balances.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it balances = nil unless hash['balances'].nil? balances = [] hash['balances'].each do |structure| balances << (BalanceAmount.from_hash(structure) if structure) end end balances = SKIP unless hash.key?('balances') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CustomerBalances.new(balances: balances, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/loyalty_ap_is/models/customer_balances.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['balances'] = 'balances' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/loyalty_ap_is/models/customer_balances.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/loyalty_ap_is/models/customer_balances.rb', line 24 def self.optionals %w[ balances ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/loyalty_ap_is/models/customer_balances.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} balances: #{@balances.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 |
# File 'lib/loyalty_ap_is/models/customer_balances.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} balances: #{@balances}, additional_properties: #{@additional_properties}>" end |