Class: LoyaltyApIs::Fault
- Defined in:
- lib/loyalty_ap_is/models/fault.rb
Overview
Fault Model.
Instance Attribute Summary collapse
-
#detail ⇒ FaultDetail
The description of the error.
-
#faultstring ⇒ String
The description of the error.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(faultstring: SKIP, detail: SKIP, additional_properties: nil) ⇒ Fault
constructor
A new instance of Fault.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(faultstring: SKIP, detail: SKIP, additional_properties: nil) ⇒ Fault
Returns a new instance of Fault.
41 42 43 44 45 46 47 48 |
# File 'lib/loyalty_ap_is/models/fault.rb', line 41 def initialize(faultstring: SKIP, detail: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @faultstring = faultstring unless faultstring == SKIP @detail = detail unless detail == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#detail ⇒ FaultDetail
The description of the error.
18 19 20 |
# File 'lib/loyalty_ap_is/models/fault.rb', line 18 def detail @detail end |
#faultstring ⇒ String
The description of the error.
14 15 16 |
# File 'lib/loyalty_ap_is/models/fault.rb', line 14 def faultstring @faultstring end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/loyalty_ap_is/models/fault.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. faultstring = hash.key?('faultstring') ? hash['faultstring'] : SKIP detail = FaultDetail.from_hash(hash['detail']) if hash['detail'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Fault.new(faultstring: faultstring, detail: detail, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/loyalty_ap_is/models/fault.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['faultstring'] = 'faultstring' @_hash['detail'] = 'detail' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/loyalty_ap_is/models/fault.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/loyalty_ap_is/models/fault.rb', line 29 def self.optionals %w[ faultstring detail ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/loyalty_ap_is/models/fault.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} faultstring: #{@faultstring.inspect}, detail: #{@detail.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/loyalty_ap_is/models/fault.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} faultstring: #{@faultstring}, detail: #{@detail}, additional_properties:"\ " #{@additional_properties}>" end |