Class: LoyaltyApIs::LoyaltyCardInfo
- Defined in:
- lib/loyalty_ap_is/models/loyalty_card_info.rb
Overview
LoyaltyCardInfo Model.
Instance Attribute Summary collapse
-
#loyalty_card ⇒ String
Loyalty card of the transaction.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(loyalty_card: SKIP, additional_properties: nil) ⇒ LoyaltyCardInfo
constructor
A new instance of LoyaltyCardInfo.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(loyalty_card: SKIP, additional_properties: nil) ⇒ LoyaltyCardInfo
Returns a new instance of LoyaltyCardInfo.
35 36 37 38 39 40 41 |
# File 'lib/loyalty_ap_is/models/loyalty_card_info.rb', line 35 def initialize(loyalty_card: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @loyalty_card = loyalty_card unless loyalty_card == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#loyalty_card ⇒ String
Loyalty card of the transaction.
14 15 16 |
# File 'lib/loyalty_ap_is/models/loyalty_card_info.rb', line 14 def loyalty_card @loyalty_card end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/loyalty_ap_is/models/loyalty_card_info.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. loyalty_card = hash.key?('loyaltyCard') ? hash['loyaltyCard'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LoyaltyCardInfo.new(loyalty_card: loyalty_card, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/loyalty_ap_is/models/loyalty_card_info.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['loyalty_card'] = 'loyaltyCard' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/loyalty_ap_is/models/loyalty_card_info.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/loyalty_ap_is/models/loyalty_card_info.rb', line 24 def self.optionals %w[ loyalty_card ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
70 71 72 73 74 |
# File 'lib/loyalty_ap_is/models/loyalty_card_info.rb', line 70 def inspect class_name = self.class.name.split('::').last "<#{class_name} loyalty_card: #{@loyalty_card.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
63 64 65 66 67 |
# File 'lib/loyalty_ap_is/models/loyalty_card_info.rb', line 63 def to_s class_name = self.class.name.split('::').last "<#{class_name} loyalty_card: #{@loyalty_card}, additional_properties:"\ " #{@additional_properties}>" end |