Class: LoyaltyApIs::PointsToCash

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/loyalty_ap_is/models/points_to_cash.rb

Overview

PointsToCash Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(points_redeemed: SKIP, total_amount: SKIP, points_to_cash_mop: SKIP, additional_properties: nil) ⇒ PointsToCash

Returns a new instance of PointsToCash.



47
48
49
50
51
52
53
54
55
56
# File 'lib/loyalty_ap_is/models/points_to_cash.rb', line 47

def initialize(points_redeemed: SKIP, total_amount: SKIP,
               points_to_cash_mop: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @points_redeemed = points_redeemed unless points_redeemed == SKIP
  @total_amount = total_amount unless total_amount == SKIP
  @points_to_cash_mop = points_to_cash_mop unless points_to_cash_mop == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#points_redeemedFloat

The points used for converting it to cash

Returns:

  • (Float)


14
15
16
# File 'lib/loyalty_ap_is/models/points_to_cash.rb', line 14

def points_redeemed
  @points_redeemed
end

#points_to_cash_mopTrueClass | FalseClass

Indication if the p2c was used as a method of payment

Returns:

  • (TrueClass | FalseClass)


22
23
24
# File 'lib/loyalty_ap_is/models/points_to_cash.rb', line 22

def points_to_cash_mop
  @points_to_cash_mop
end

#total_amountFloat

Total amount in cash used

Returns:

  • (Float)


18
19
20
# File 'lib/loyalty_ap_is/models/points_to_cash.rb', line 18

def total_amount
  @total_amount
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/loyalty_ap_is/models/points_to_cash.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  points_redeemed =
    hash.key?('pointsRedeemed') ? hash['pointsRedeemed'] : SKIP
  total_amount = hash.key?('totalAmount') ? hash['totalAmount'] : SKIP
  points_to_cash_mop =
    hash.key?('pointsToCashMOP') ? hash['pointsToCashMOP'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PointsToCash.new(points_redeemed: points_redeemed,
                   total_amount: total_amount,
                   points_to_cash_mop: points_to_cash_mop,
                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/loyalty_ap_is/models/points_to_cash.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['points_redeemed'] = 'pointsRedeemed'
  @_hash['total_amount'] = 'totalAmount'
  @_hash['points_to_cash_mop'] = 'pointsToCashMOP'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/loyalty_ap_is/models/points_to_cash.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/loyalty_ap_is/models/points_to_cash.rb', line 34

def self.optionals
  %w[
    points_redeemed
    total_amount
    points_to_cash_mop
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



92
93
94
95
96
97
# File 'lib/loyalty_ap_is/models/points_to_cash.rb', line 92

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} points_redeemed: #{@points_redeemed.inspect}, total_amount:"\
  " #{@total_amount.inspect}, points_to_cash_mop: #{@points_to_cash_mop.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
89
# File 'lib/loyalty_ap_is/models/points_to_cash.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} points_redeemed: #{@points_redeemed}, total_amount: #{@total_amount},"\
  " points_to_cash_mop: #{@points_to_cash_mop}, additional_properties:"\
  " #{@additional_properties}>"
end