Class: LoyaltyApIs::RefreshTokenResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/loyalty_ap_is/models/refresh_token_response.rb

Overview

RefreshTokenResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(access_token:, refresh_token:, expires_in:, additional_properties: nil) ⇒ RefreshTokenResponse

Returns a new instance of RefreshTokenResponse.



44
45
46
47
48
49
50
51
52
53
# File 'lib/loyalty_ap_is/models/refresh_token_response.rb', line 44

def initialize(access_token:, refresh_token:, expires_in:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @access_token = access_token
  @refresh_token = refresh_token
  @expires_in = expires_in
  @additional_properties = additional_properties
end

Instance Attribute Details

#access_tokenString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/loyalty_ap_is/models/refresh_token_response.rb', line 14

def access_token
  @access_token
end

#expires_inInteger

Indicates the number of seconds until the new access token provided in the pair expires

Returns:

  • (Integer)


23
24
25
# File 'lib/loyalty_ap_is/models/refresh_token_response.rb', line 23

def expires_in
  @expires_in
end

#refresh_tokenString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/loyalty_ap_is/models/refresh_token_response.rb', line 18

def refresh_token
  @refresh_token
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/loyalty_ap_is/models/refresh_token_response.rb', line 56

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  access_token = hash.key?('accessToken') ? hash['accessToken'] : nil
  refresh_token = hash.key?('refreshToken') ? hash['refreshToken'] : nil
  expires_in = hash.key?('expiresIn') ? hash['expiresIn'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RefreshTokenResponse.new(access_token: access_token,
                           refresh_token: refresh_token,
                           expires_in: expires_in,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/loyalty_ap_is/models/refresh_token_response.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['access_token'] = 'accessToken'
  @_hash['refresh_token'] = 'refreshToken'
  @_hash['expires_in'] = 'expiresIn'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/loyalty_ap_is/models/refresh_token_response.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
# File 'lib/loyalty_ap_is/models/refresh_token_response.rb', line 35

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



86
87
88
89
90
91
# File 'lib/loyalty_ap_is/models/refresh_token_response.rb', line 86

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} access_token: #{@access_token.inspect}, refresh_token:"\
  " #{@refresh_token.inspect}, expires_in: #{@expires_in.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



79
80
81
82
83
# File 'lib/loyalty_ap_is/models/refresh_token_response.rb', line 79

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} access_token: #{@access_token}, refresh_token: #{@refresh_token},"\
  " expires_in: #{@expires_in}, additional_properties: #{@additional_properties}>"
end