Class: LoyaltyApIs::TransactionsResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/loyalty_ap_is/models/transactions_response.rb

Overview

TransactionsResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(total_results:, next_page:, previous_page:, total_saved:, transactions:, additional_properties: nil) ⇒ TransactionsResponse

Returns a new instance of TransactionsResponse.



53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/loyalty_ap_is/models/transactions_response.rb', line 53

def initialize(total_results:, next_page:, previous_page:, total_saved:,
               transactions:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @total_results = total_results
  @next_page = next_page
  @previous_page = previous_page
  @total_saved = total_saved
  @transactions = transactions
  @additional_properties = additional_properties
end

Instance Attribute Details

#next_pageString

API URI which must be used to retrieve the next page of resources

Returns:

  • (String)


18
19
20
# File 'lib/loyalty_ap_is/models/transactions_response.rb', line 18

def next_page
  @next_page
end

#previous_pageString

API URI which must be used to retrieve the previous page of resources

Returns:

  • (String)


22
23
24
# File 'lib/loyalty_ap_is/models/transactions_response.rb', line 22

def previous_page
  @previous_page
end

#total_resultsInteger

Total no of resource which will be sent back across all pages

Returns:

  • (Integer)


14
15
16
# File 'lib/loyalty_ap_is/models/transactions_response.rb', line 14

def total_results
  @total_results
end

#total_savedFloat

Total amount saved so far

Returns:

  • (Float)


26
27
28
# File 'lib/loyalty_ap_is/models/transactions_response.rb', line 26

def total_saved
  @total_saved
end

#transactionsArray[Transaction]

Transactions list

Returns:



30
31
32
# File 'lib/loyalty_ap_is/models/transactions_response.rb', line 30

def transactions
  @transactions
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/loyalty_ap_is/models/transactions_response.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  total_results = hash.key?('totalResults') ? hash['totalResults'] : nil
  next_page = hash.key?('nextPage') ? hash['nextPage'] : nil
  previous_page = hash.key?('previousPage') ? hash['previousPage'] : nil
  total_saved = hash.key?('totalSaved') ? hash['totalSaved'] : nil
  # Parameter is an array, so we need to iterate through it
  transactions = nil
  unless hash['transactions'].nil?
    transactions = []
    hash['transactions'].each do |structure|
      transactions << (Transaction.from_hash(structure) if structure)
    end
  end

  transactions = nil unless hash.key?('transactions')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransactionsResponse.new(total_results: total_results,
                           next_page: next_page,
                           previous_page: previous_page,
                           total_saved: total_saved,
                           transactions: transactions,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/loyalty_ap_is/models/transactions_response.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['total_results'] = 'totalResults'
  @_hash['next_page'] = 'nextPage'
  @_hash['previous_page'] = 'previousPage'
  @_hash['total_saved'] = 'totalSaved'
  @_hash['transactions'] = 'transactions'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/loyalty_ap_is/models/transactions_response.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
# File 'lib/loyalty_ap_is/models/transactions_response.rb', line 44

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



111
112
113
114
115
116
# File 'lib/loyalty_ap_is/models/transactions_response.rb', line 111

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} total_results: #{@total_results.inspect}, next_page: #{@next_page.inspect},"\
  " previous_page: #{@previous_page.inspect}, total_saved: #{@total_saved.inspect},"\
  " transactions: #{@transactions.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



103
104
105
106
107
108
# File 'lib/loyalty_ap_is/models/transactions_response.rb', line 103

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} total_results: #{@total_results}, next_page: #{@next_page}, previous_page:"\
  " #{@previous_page}, total_saved: #{@total_saved}, transactions: #{@transactions},"\
  " additional_properties: #{@additional_properties}>"
end