Class: LoyaltyApIs::UnprocessableEntityErrorResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- LoyaltyApIs::UnprocessableEntityErrorResponse
- Defined in:
- lib/loyalty_ap_is/models/unprocessable_entity_error_response.rb
Overview
UnprocessableEntityErrorResponse Model.
Instance Attribute Summary collapse
-
#error ⇒ ErrorInfo
HTTP error message - Unprocessable entity.
-
#error_code ⇒ Float
HTTP error code 422.
-
#message ⇒ String
HTTP error message - Unprocessable entity.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(error_code:, message:, error:, additional_properties: nil) ⇒ UnprocessableEntityErrorResponse
constructor
A new instance of UnprocessableEntityErrorResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(error_code:, message:, error:, additional_properties: nil) ⇒ UnprocessableEntityErrorResponse
Returns a new instance of UnprocessableEntityErrorResponse.
43 44 45 46 47 48 49 50 51 |
# File 'lib/loyalty_ap_is/models/unprocessable_entity_error_response.rb', line 43 def initialize(error_code:, message:, error:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @error_code = error_code @message = @error = error @additional_properties = additional_properties end |
Instance Attribute Details
#error ⇒ ErrorInfo
HTTP error message - Unprocessable entity
22 23 24 |
# File 'lib/loyalty_ap_is/models/unprocessable_entity_error_response.rb', line 22 def error @error end |
#error_code ⇒ Float
HTTP error code 422
14 15 16 |
# File 'lib/loyalty_ap_is/models/unprocessable_entity_error_response.rb', line 14 def error_code @error_code end |
#message ⇒ String
HTTP error message - Unprocessable entity
18 19 20 |
# File 'lib/loyalty_ap_is/models/unprocessable_entity_error_response.rb', line 18 def @message end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/loyalty_ap_is/models/unprocessable_entity_error_response.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. error_code = hash.key?('errorCode') ? hash['errorCode'] : nil = hash.key?('message') ? hash['message'] : nil error = ErrorInfo.from_hash(hash['error']) if hash['error'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UnprocessableEntityErrorResponse.new(error_code: error_code, message: , error: error, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/loyalty_ap_is/models/unprocessable_entity_error_response.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['error_code'] = 'errorCode' @_hash['message'] = 'message' @_hash['error'] = 'error' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/loyalty_ap_is/models/unprocessable_entity_error_response.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/loyalty_ap_is/models/unprocessable_entity_error_response.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/loyalty_ap_is/models/unprocessable_entity_error_response.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} error_code: #{@error_code.inspect}, message: #{@message.inspect}, error:"\ " #{@error.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 81 |
# File 'lib/loyalty_ap_is/models/unprocessable_entity_error_response.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} error_code: #{@error_code}, message: #{@message}, error: #{@error},"\ " additional_properties: #{@additional_properties}>" end |