Class: LoyaltyApIs::CurrencyData
- Defined in:
- lib/loyalty_ap_is/models/currency_data.rb
Overview
currencyData is only filled, where there is possible non-same currency cross-border transaction
Instance Attribute Summary collapse
-
#code ⇒ String
Currency code.
-
#has_space ⇒ TrueClass | FalseClass
Currency format (is there a space between the symbol and the value).
-
#is_suffix ⇒ TrueClass | FalseClass
Currency format (is the symbol after the value).
-
#symbol ⇒ String
Currency symbol.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(code:, symbol:, is_suffix:, has_space:, additional_properties: nil) ⇒ CurrencyData
constructor
A new instance of CurrencyData.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(code:, symbol:, is_suffix:, has_space:, additional_properties: nil) ⇒ CurrencyData
Returns a new instance of CurrencyData.
49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/loyalty_ap_is/models/currency_data.rb', line 49 def initialize(code:, symbol:, is_suffix:, has_space:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @code = code @symbol = symbol @is_suffix = is_suffix @has_space = has_space @additional_properties = additional_properties end |
Instance Attribute Details
#code ⇒ String
Currency code
15 16 17 |
# File 'lib/loyalty_ap_is/models/currency_data.rb', line 15 def code @code end |
#has_space ⇒ TrueClass | FalseClass
Currency format (is there a space between the symbol and the value)
27 28 29 |
# File 'lib/loyalty_ap_is/models/currency_data.rb', line 27 def has_space @has_space end |
#is_suffix ⇒ TrueClass | FalseClass
Currency format (is the symbol after the value)
23 24 25 |
# File 'lib/loyalty_ap_is/models/currency_data.rb', line 23 def is_suffix @is_suffix end |
#symbol ⇒ String
Currency symbol
19 20 21 |
# File 'lib/loyalty_ap_is/models/currency_data.rb', line 19 def symbol @symbol end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/loyalty_ap_is/models/currency_data.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. code = hash.key?('code') ? hash['code'] : nil symbol = hash.key?('symbol') ? hash['symbol'] : nil is_suffix = hash.key?('isSuffix') ? hash['isSuffix'] : nil has_space = hash.key?('hasSpace') ? hash['hasSpace'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CurrencyData.new(code: code, symbol: symbol, is_suffix: is_suffix, has_space: has_space, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
30 31 32 33 34 35 36 37 |
# File 'lib/loyalty_ap_is/models/currency_data.rb', line 30 def self.names @_hash = {} if @_hash.nil? @_hash['code'] = 'code' @_hash['symbol'] = 'symbol' @_hash['is_suffix'] = 'isSuffix' @_hash['has_space'] = 'hasSpace' @_hash end |
.nullables ⇒ Object
An array for nullable fields
45 46 47 |
# File 'lib/loyalty_ap_is/models/currency_data.rb', line 45 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
40 41 42 |
# File 'lib/loyalty_ap_is/models/currency_data.rb', line 40 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
94 95 96 97 98 99 |
# File 'lib/loyalty_ap_is/models/currency_data.rb', line 94 def inspect class_name = self.class.name.split('::').last "<#{class_name} code: #{@code.inspect}, symbol: #{@symbol.inspect}, is_suffix:"\ " #{@is_suffix.inspect}, has_space: #{@has_space.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 91 |
# File 'lib/loyalty_ap_is/models/currency_data.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} code: #{@code}, symbol: #{@symbol}, is_suffix: #{@is_suffix}, has_space:"\ " #{@has_space}, additional_properties: #{@additional_properties}>" end |