Class: LoyaltyApIs::ErrorItem
- Defined in:
- lib/loyalty_ap_is/models/error_item.rb
Overview
ErrorItem Model.
Instance Attribute Summary collapse
-
#detail ⇒ String
TODO: Write general description for this method.
-
#source ⇒ ErrorSource
TODO: Write general description for this method.
-
#status ⇒ Integer
TODO: Write general description for this method.
-
#title ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(status: SKIP, title: SKIP, source: SKIP, detail: SKIP, additional_properties: nil) ⇒ ErrorItem
constructor
A new instance of ErrorItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(status: SKIP, title: SKIP, source: SKIP, detail: SKIP, additional_properties: nil) ⇒ ErrorItem
Returns a new instance of ErrorItem.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/loyalty_ap_is/models/error_item.rb', line 53 def initialize(status: SKIP, title: SKIP, source: SKIP, detail: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @status = status unless status == SKIP @title = title unless title == SKIP @source = source unless source == SKIP @detail = detail unless detail == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#detail ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/loyalty_ap_is/models/error_item.rb', line 26 def detail @detail end |
#source ⇒ ErrorSource
TODO: Write general description for this method
22 23 24 |
# File 'lib/loyalty_ap_is/models/error_item.rb', line 22 def source @source end |
#status ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/loyalty_ap_is/models/error_item.rb', line 14 def status @status end |
#title ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/loyalty_ap_is/models/error_item.rb', line 18 def title @title end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/loyalty_ap_is/models/error_item.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. status = hash.key?('status') ? hash['status'] : SKIP title = hash.key?('title') ? hash['title'] : SKIP source = ErrorSource.from_hash(hash['source']) if hash['source'] detail = hash.key?('detail') ? hash['detail'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ErrorItem.new(status: status, title: title, source: source, detail: detail, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/loyalty_ap_is/models/error_item.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['status'] = 'status' @_hash['title'] = 'title' @_hash['source'] = 'source' @_hash['detail'] = 'detail' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/loyalty_ap_is/models/error_item.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/loyalty_ap_is/models/error_item.rb', line 39 def self.optionals %w[ status title source detail ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 103 |
# File 'lib/loyalty_ap_is/models/error_item.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} status: #{@status.inspect}, title: #{@title.inspect}, source:"\ " #{@source.inspect}, detail: #{@detail.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/loyalty_ap_is/models/error_item.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} status: #{@status}, title: #{@title}, source: #{@source}, detail:"\ " #{@detail}, additional_properties: #{@additional_properties}>" end |