Class: LoyaltyApIs::M200UserPartners
- Defined in:
- lib/loyalty_ap_is/models/m200_user_partners.rb
Overview
M200UserPartners Model.
Instance Attribute Summary collapse
-
#access_token ⇒ String
TODO: Write general description for this method.
-
#market ⇒ Object
TODO: Write general description for this method.
-
#refresh_token ⇒ String
TODO: Write general description for this method.
-
#user_status ⇒ String
TODO: Write general description for this method.
-
#uuid ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(uuid:, user_status:, market:, access_token:, refresh_token:, additional_properties: nil) ⇒ M200UserPartners
constructor
A new instance of M200UserPartners.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(uuid:, user_status:, market:, access_token:, refresh_token:, additional_properties: nil) ⇒ M200UserPartners
Returns a new instance of M200UserPartners.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/loyalty_ap_is/models/m200_user_partners.rb', line 53 def initialize(uuid:, user_status:, market:, access_token:, refresh_token:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @uuid = uuid @user_status = user_status @market = market @access_token = access_token @refresh_token = refresh_token @additional_properties = additional_properties end |
Instance Attribute Details
#access_token ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/loyalty_ap_is/models/m200_user_partners.rb', line 26 def access_token @access_token end |
#market ⇒ Object
TODO: Write general description for this method
22 23 24 |
# File 'lib/loyalty_ap_is/models/m200_user_partners.rb', line 22 def market @market end |
#refresh_token ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/loyalty_ap_is/models/m200_user_partners.rb', line 30 def refresh_token @refresh_token end |
#user_status ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/loyalty_ap_is/models/m200_user_partners.rb', line 18 def user_status @user_status end |
#uuid ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/loyalty_ap_is/models/m200_user_partners.rb', line 14 def uuid @uuid end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/loyalty_ap_is/models/m200_user_partners.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. uuid = hash.key?('uuid') ? hash['uuid'] : nil user_status = hash.key?('userStatus') ? hash['userStatus'] : nil market = hash.key?('market') ? hash['market'] : nil access_token = hash.key?('accessToken') ? hash['accessToken'] : nil refresh_token = hash.key?('refreshToken') ? hash['refreshToken'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. M200UserPartners.new(uuid: uuid, user_status: user_status, market: market, access_token: access_token, refresh_token: refresh_token, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/loyalty_ap_is/models/m200_user_partners.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['uuid'] = 'uuid' @_hash['user_status'] = 'userStatus' @_hash['market'] = 'market' @_hash['access_token'] = 'accessToken' @_hash['refresh_token'] = 'refreshToken' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/loyalty_ap_is/models/m200_user_partners.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/loyalty_ap_is/models/m200_user_partners.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
102 103 104 105 106 107 |
# File 'lib/loyalty_ap_is/models/m200_user_partners.rb', line 102 def inspect class_name = self.class.name.split('::').last "<#{class_name} uuid: #{@uuid.inspect}, user_status: #{@user_status.inspect}, market:"\ " #{@market.inspect}, access_token: #{@access_token.inspect}, refresh_token:"\ " #{@refresh_token.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
94 95 96 97 98 99 |
# File 'lib/loyalty_ap_is/models/m200_user_partners.rb', line 94 def to_s class_name = self.class.name.split('::').last "<#{class_name} uuid: #{@uuid}, user_status: #{@user_status}, market: #{@market},"\ " access_token: #{@access_token}, refresh_token: #{@refresh_token}, additional_properties:"\ " #{@additional_properties}>" end |