Class: LoyaltyApIs::OfferBase
- Defined in:
- lib/loyalty_ap_is/models/offer_base.rb
Overview
OfferBase Model.
Instance Attribute Summary collapse
-
#description ⇒ String
Description of the partner's offer, set up upon offer configuration.
-
#offer_id ⇒ Integer
Offer ID provided upon offer configuration.
-
#reference_id ⇒ String
Unique Reference ID for the transaction from the partner.
-
#title ⇒ String
Title of the partner's offer, given upon configuration.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(offer_id:, reference_id:, title:, description:, additional_properties: nil) ⇒ OfferBase
constructor
A new instance of OfferBase.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(offer_id:, reference_id:, title:, description:, additional_properties: nil) ⇒ OfferBase
Returns a new instance of OfferBase.
49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/loyalty_ap_is/models/offer_base.rb', line 49 def initialize(offer_id:, reference_id:, title:, description:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @offer_id = offer_id @reference_id = reference_id @title = title @description = description @additional_properties = additional_properties end |
Instance Attribute Details
#description ⇒ String
Description of the partner's offer, set up upon offer configuration
27 28 29 |
# File 'lib/loyalty_ap_is/models/offer_base.rb', line 27 def description @description end |
#offer_id ⇒ Integer
Offer ID provided upon offer configuration
14 15 16 |
# File 'lib/loyalty_ap_is/models/offer_base.rb', line 14 def offer_id @offer_id end |
#reference_id ⇒ String
Unique Reference ID for the transaction from the partner. Used to identify duplicate requests.
19 20 21 |
# File 'lib/loyalty_ap_is/models/offer_base.rb', line 19 def reference_id @reference_id end |
#title ⇒ String
Title of the partner's offer, given upon configuration
23 24 25 |
# File 'lib/loyalty_ap_is/models/offer_base.rb', line 23 def title @title end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/loyalty_ap_is/models/offer_base.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. offer_id = hash.key?('offerId') ? hash['offerId'] : nil reference_id = hash.key?('referenceId') ? hash['referenceId'] : nil title = hash.key?('title') ? hash['title'] : nil description = hash.key?('description') ? hash['description'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. OfferBase.new(offer_id: offer_id, reference_id: reference_id, title: title, description: description, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
30 31 32 33 34 35 36 37 |
# File 'lib/loyalty_ap_is/models/offer_base.rb', line 30 def self.names @_hash = {} if @_hash.nil? @_hash['offer_id'] = 'offerId' @_hash['reference_id'] = 'referenceId' @_hash['title'] = 'title' @_hash['description'] = 'description' @_hash end |
.nullables ⇒ Object
An array for nullable fields
45 46 47 |
# File 'lib/loyalty_ap_is/models/offer_base.rb', line 45 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
40 41 42 |
# File 'lib/loyalty_ap_is/models/offer_base.rb', line 40 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
94 95 96 97 98 99 |
# File 'lib/loyalty_ap_is/models/offer_base.rb', line 94 def inspect class_name = self.class.name.split('::').last "<#{class_name} offer_id: #{@offer_id.inspect}, reference_id: #{@reference_id.inspect},"\ " title: #{@title.inspect}, description: #{@description.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 91 |
# File 'lib/loyalty_ap_is/models/offer_base.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} offer_id: #{@offer_id}, reference_id: #{@reference_id}, title: #{@title},"\ " description: #{@description}, additional_properties: #{@additional_properties}>" end |