Class: LoyaltyApIs::SiteData
- Defined in:
- lib/loyalty_ap_is/models/site_data.rb
Overview
SiteData Model.
Instance Attribute Summary collapse
-
#address ⇒ String
Address of the site.
-
#city ⇒ String
City of the site.
-
#country_code ⇒ String
Two character ISO 3166-1 alpha-2 country code.
-
#name ⇒ String
Name of the site.
-
#postcode ⇒ String
Postcode of the site.
-
#site_id ⇒ String
Unique Id of the site.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(country_code:, site_id:, name:, postcode: SKIP, city: SKIP, address: SKIP, additional_properties: nil) ⇒ SiteData
constructor
A new instance of SiteData.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(country_code:, site_id:, name:, postcode: SKIP, city: SKIP, address: SKIP, additional_properties: nil) ⇒ SiteData
Returns a new instance of SiteData.
62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/loyalty_ap_is/models/site_data.rb', line 62 def initialize(country_code:, site_id:, name:, postcode: SKIP, city: SKIP, address: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @country_code = country_code @site_id = site_id @name = name @postcode = postcode unless postcode == SKIP @city = city unless city == SKIP @address = address unless address == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#address ⇒ String
Address of the site
34 35 36 |
# File 'lib/loyalty_ap_is/models/site_data.rb', line 34 def address @address end |
#city ⇒ String
City of the site
30 31 32 |
# File 'lib/loyalty_ap_is/models/site_data.rb', line 30 def city @city end |
#country_code ⇒ String
Two character ISO 3166-1 alpha-2 country code
14 15 16 |
# File 'lib/loyalty_ap_is/models/site_data.rb', line 14 def country_code @country_code end |
#name ⇒ String
Name of the site
22 23 24 |
# File 'lib/loyalty_ap_is/models/site_data.rb', line 22 def name @name end |
#postcode ⇒ String
Postcode of the site
26 27 28 |
# File 'lib/loyalty_ap_is/models/site_data.rb', line 26 def postcode @postcode end |
#site_id ⇒ String
Unique Id of the site
18 19 20 |
# File 'lib/loyalty_ap_is/models/site_data.rb', line 18 def site_id @site_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/loyalty_ap_is/models/site_data.rb', line 77 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. country_code = hash.key?('countryCode') ? hash['countryCode'] : nil site_id = hash.key?('siteId') ? hash['siteId'] : nil name = hash.key?('name') ? hash['name'] : nil postcode = hash.key?('postcode') ? hash['postcode'] : SKIP city = hash.key?('city') ? hash['city'] : SKIP address = hash.key?('address') ? hash['address'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SiteData.new(country_code: country_code, site_id: site_id, name: name, postcode: postcode, city: city, address: address, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/loyalty_ap_is/models/site_data.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['country_code'] = 'countryCode' @_hash['site_id'] = 'siteId' @_hash['name'] = 'name' @_hash['postcode'] = 'postcode' @_hash['city'] = 'city' @_hash['address'] = 'address' @_hash end |
.nullables ⇒ Object
An array for nullable fields
58 59 60 |
# File 'lib/loyalty_ap_is/models/site_data.rb', line 58 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 54 55 |
# File 'lib/loyalty_ap_is/models/site_data.rb', line 49 def self.optionals %w[ postcode city address ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
114 115 116 117 118 119 |
# File 'lib/loyalty_ap_is/models/site_data.rb', line 114 def inspect class_name = self.class.name.split('::').last "<#{class_name} country_code: #{@country_code.inspect}, site_id: #{@site_id.inspect}, name:"\ " #{@name.inspect}, postcode: #{@postcode.inspect}, city: #{@city.inspect}, address:"\ " #{@address.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
106 107 108 109 110 111 |
# File 'lib/loyalty_ap_is/models/site_data.rb', line 106 def to_s class_name = self.class.name.split('::').last "<#{class_name} country_code: #{@country_code}, site_id: #{@site_id}, name: #{@name},"\ " postcode: #{@postcode}, city: #{@city}, address: #{@address}, additional_properties:"\ " #{@additional_properties}>" end |