Class: LoyaltyApIs::VoucherItem
- Defined in:
- lib/loyalty_ap_is/models/voucher_item.rb
Overview
VoucherItem Model.
Instance Attribute Summary collapse
-
#code ⇒ String
Voucher code.
-
#expiry_date ⇒ Integer
Expiry date as Unix epoch (UTC), as requested by MobGen.
-
#expiry_date_timestamp ⇒ DateTime
Expiry date in JSON recommended format: “yyyy-MM-ddTHH:mm:ssZ”.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(code:, expiry_date:, expiry_date_timestamp:, additional_properties: nil) ⇒ VoucherItem
constructor
A new instance of VoucherItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_expiry_date_timestamp ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(code:, expiry_date:, expiry_date_timestamp:, additional_properties: nil) ⇒ VoucherItem
Returns a new instance of VoucherItem.
44 45 46 47 48 49 50 51 52 53 |
# File 'lib/loyalty_ap_is/models/voucher_item.rb', line 44 def initialize(code:, expiry_date:, expiry_date_timestamp:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @code = code @expiry_date = expiry_date @expiry_date_timestamp = @additional_properties = additional_properties end |
Instance Attribute Details
#code ⇒ String
Voucher code
15 16 17 |
# File 'lib/loyalty_ap_is/models/voucher_item.rb', line 15 def code @code end |
#expiry_date ⇒ Integer
Expiry date as Unix epoch (UTC), as requested by MobGen.
19 20 21 |
# File 'lib/loyalty_ap_is/models/voucher_item.rb', line 19 def expiry_date @expiry_date end |
#expiry_date_timestamp ⇒ DateTime
Expiry date in JSON recommended format: “yyyy-MM-ddTHH:mm:ssZ”
23 24 25 |
# File 'lib/loyalty_ap_is/models/voucher_item.rb', line 23 def @expiry_date_timestamp end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/loyalty_ap_is/models/voucher_item.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. code = hash.key?('code') ? hash['code'] : nil expiry_date = hash.key?('expiryDate') ? hash['expiryDate'] : nil = if hash.key?('expiryDateTimestamp') (DateTimeHelper.from_rfc3339(hash['expiryDateTimestamp']) if hash['expiryDateTimestamp']) end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. VoucherItem.new(code: code, expiry_date: expiry_date, expiry_date_timestamp: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/loyalty_ap_is/models/voucher_item.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['code'] = 'code' @_hash['expiry_date'] = 'expiryDate' @_hash['expiry_date_timestamp'] = 'expiryDateTimestamp' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/loyalty_ap_is/models/voucher_item.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/loyalty_ap_is/models/voucher_item.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
92 93 94 95 96 97 |
# File 'lib/loyalty_ap_is/models/voucher_item.rb', line 92 def inspect class_name = self.class.name.split('::').last "<#{class_name} code: #{@code.inspect}, expiry_date: #{@expiry_date.inspect},"\ " expiry_date_timestamp: #{@expiry_date_timestamp.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_custom_expiry_date_timestamp ⇒ Object
80 81 82 |
# File 'lib/loyalty_ap_is/models/voucher_item.rb', line 80 def DateTimeHelper.to_rfc3339() end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
85 86 87 88 89 |
# File 'lib/loyalty_ap_is/models/voucher_item.rb', line 85 def to_s class_name = self.class.name.split('::').last "<#{class_name} code: #{@code}, expiry_date: #{@expiry_date}, expiry_date_timestamp:"\ " #{@expiry_date_timestamp}, additional_properties: #{@additional_properties}>" end |